@@ -5,6 +5,7 @@ header('Content-Type: application/json');
 // Check API permission
 check_api_permission('sites');
 
+require_once '../libs/mysqlmgmt.php';
 require_once '../libs/docker-api.php';
 
 if (!isset($_GET['site_id']) || !is_numeric($_GET['site_id'])) {
@@ -16,15 +17,17 @@ if (!isset($_GET['site_id']) || !is_numeric($_GET['site_id'])) {
 $site_id = intval($_GET['site_id']);
 
 try {
-    $db = get_db_connection();
+    $MySQLMgmt = new mysqlmgmt();
+    $db = $MySQLMgmt->getMySQLConnection();
     
     // Verify user owns this site (unless root)
-    if ($_SESSION['username'] !== 'root') {
+    $is_root = (defined('AUTH_USER') && AUTH_USER === 'root');
+    if (!$is_root) {
         $stmt = $db->prepare("SELECT username FROM whp.sites WHERE id = ?");
         $stmt->execute([$site_id]);
         $site = $stmt->fetch(PDO::FETCH_ASSOC);
         
-        if (!$site || $site['username'] !== $_SESSION['username']) {
+        if (!$site || $site['username'] !== AUTH_USER) {
             http_response_code(403);
             echo json_encode(['success' => false, 'error' => 'Access denied']);
             exit;
@@ -41,7 +44,7 @@ try {
         exit;
     }
     
-    $docker_api = new DockerAPI();
+    $docker_api = new docker_api();
     $all_ready = true;
     $container_statuses = [];
     
