@@ -80,8 +80,16 @@ try {
         exit;
     }
 
-    // DNS validation
-    if (!$PowerDNS->verifyFQDNHasRecord($primary_fqdn)) {
+    // Validate FQDN is a valid A or CNAME for this domain
+    $valid_fqdn = false;
+    $fqdn_records = $PowerDNS->getRecords($primary_domain_row['domain_name']);
+    foreach ($fqdn_records as $rec) {
+        if (strcasecmp($rec['name'], $primary_fqdn) === 0 && in_array(strtoupper($rec['type']), ['A','CNAME'])) {
+            $valid_fqdn = true;
+            break;
+        }
+    }
+    if (!$valid_fqdn) {
         http_response_code(400);
         echo json_encode(['success' => false, 'error' => 'DNS validation failed: No A or CNAME record found for ' . $primary_fqdn]);
         exit;
@@ -163,7 +171,18 @@ try {
                 }
             }
 
-            if ($parent_row && $PowerDNS->verifyFQDNHasRecord($additional_fqdn)) {
+            if ($parent_row) {
+                // Validate additional FQDN has valid A or CNAME record
+                $valid_fqdn = false;
+                $fqdn_records = $PowerDNS->getRecords($parent_row['domain_name']);
+                foreach ($fqdn_records as $rec) {
+                    if (strcasecmp($rec['name'], $additional_fqdn) === 0 && in_array(strtoupper($rec['type']), ['A','CNAME'])) {
+                        $valid_fqdn = true;
+                        break;
+                    }
+                }
+                
+                if ($valid_fqdn) {
                 // Check if not already linked
                 $stmt = $db->prepare("SELECT id FROM whp.site_domains WHERE site_id = ? AND domain_id = ? AND fqdn = ?");
                 $stmt->execute([$site_id, $parent_row['id'], $additional_fqdn]);
@@ -173,6 +192,7 @@ try {
                     $stmt->execute([$site_id, $parent_row['id'], $additional_fqdn]);
                     $additional_domains_added[] = $additional_fqdn;
                 }
+                }
             }
         }
     }
