@@ -92,6 +92,15 @@ try {
             echo json_encode($result);
             exit;
             
+        case 'update_all':
+            if (!check_permission('wordpress_update')) {
+                throw new Exception('Permission denied');
+            }
+            $result = $wpManager->updateAll($_POST['site_id']);
+            ob_clean(); // Clear buffer before output
+            echo json_encode($result);
+            exit;
+            
         case 'reset_password':
             $result = $wpManager->resetAdminPassword($_POST['site_id'], $_POST['new_password'] ?? null);
             ob_clean(); // Clear buffer before output
