@@ -213,7 +213,7 @@ $backupTargets = $stmt->fetchAll(PDO::FETCH_ASSOC);
                                                     </li>
                                                     <li>
                                                         <a class="dropdown-item" href="#" onclick="showUpdateModal(<?php echo $site['id']; ?>)">
-                                                            <i class="fa fa-sync"></i> Update Core
+                                                            <i class="fa fa-sync"></i> Update Now
                                                         </a>
                                                     </li>
                                                     <li>
@@ -1672,13 +1672,13 @@ function createLoginLink(siteId) {
 }
 
 function showUpdateModal(siteId) {
-    if (confirm('Update WordPress core? A backup will be created automatically.')) {
+    if (confirm('Update WordPress (core, plugins, and themes)? A backup will be created automatically.')) {
         const formData = new FormData();
-        formData.append('action', 'update_core');
+        formData.append('action', 'update_all');
         formData.append('site_id', siteId);
         
         // Show progress alert
-        showAlert('info', 'WordPress update started in background. This may take a few minutes...', false);
+        showAlert('info', 'WordPress complete update started in background. This may take several minutes...', false);
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
